[llvm-commits] CVS: llvm/utils/NightlyTest.pl NightlyTestTemplate.html

Reid Spencer reid at x10sys.com
Mon Dec 6 12:14:56 PST 2004



Changes in directory llvm/utils:

NightlyTest.pl updated: 1.80 -> 1.81
NightlyTestTemplate.html updated: 1.37 -> 1.38
---
Log message:

Revert previous changes to remove -enable-linscan and the *BETA columns of
the nightly test. These are still needed for iterative linear scan testing.


---
Diffs of the changes:  (+5 -2)

Index: llvm/utils/NightlyTestTemplate.html
diff -u llvm/utils/NightlyTestTemplate.html:1.37 llvm/utils/NightlyTestTemplate.html:1.38
--- llvm/utils/NightlyTestTemplate.html:1.37	Mon Dec  6 12:29:14 2004
+++ llvm/utils/NightlyTestTemplate.html	Mon Dec  6 14:14:45 2004
@@ -215,6 +215,9 @@
     GCC output: greater than 1 is a speedup, less than 1 is a slowdown.</li>
 <li><a name="GCC/CBE">GCC/CBE</a> - The speed-up of the CBE output vs the native 
     GCC output: greater than 1 is a speedup, less than 1 is a slowdown.</li>
+<li><a name="LLC-BETA">LLC-BETA</a> - How long does the program generated by the static
+    backend LLC take to execute the program, when compiled with new experimental 
+    features.  This is temporary, for tuning.</li>
 </ol><p>
 
 A complete log of testing 






More information about the llvm-commits mailing list
Index: llvm/utils/NightlyTest.pl
diff -u llvm/utils/NightlyTest.pl:1.80 llvm/utils/NightlyTest.pl:1.81
--- llvm/utils/NightlyTest.pl:1.80	Mon Dec  6 12:33:54 2004
+++ llvm/utils/NightlyTest.pl	Mon Dec  6 14:14:45 2004
@@ -23,7 +23,7 @@
 #  -parallel        Run two parallel jobs with GNU Make.
 #  -release         Build an LLVM Release version
 #  -pedantic        Enable additional GCC warnings to detect possible errors.
 #  -enable-linscan  Accepted but ignored
 #  -disable-llc     Disable LLC tests in the nightly tester.
 #  -disable-jit     Disable JIT tests in the nightly tester.
 #  -verbose         Turn on some debug output
@@ -260,7 +260,7 @@
       $MAKEOPTS   = "$MAKEOPTS CompileOptimizeOpts='-O3 -DNDEBUG -finline-functions -Wpointer-arith -Wcast-align -Wno-deprecated -Wold-style-cast -Wabi -Woverloaded-virtual -ffor-scope'"; 
       next; 
   }
-  if (/^-enable-linscan$/) { next; }
+  if (/^-enable-linscan$/) { $PROGTESTOPTS .= " ENABLE_LINEARSCAN=1"; next; }
   if (/^-disable-llc$/)    { $PROGTESTOPTS .= " DISABLE_LLC=1";
                              $CONFIGUREARGS .= " --disable-llc_diffs"; next; }
   if (/^-disable-jit$/)    { $PROGTESTOPTS .= " DISABLE_JIT=1";
@@ -23,7 +23,7 @@
 #  -release         Build an LLVM Release version
 #  -pedantic        Enable additional GCC warnings to detect possible errors.
-#  -enable-linscan  Accepted but ignored
+#  -enable-linscan  Enable linearscan tests
 #  -disable-llc     Disable LLC tests in the nightly tester.
 #  -disable-jit     Disable JIT tests in the nightly tester.

